==> cost-interface-0.3.13-sources.jar: com/chinayanghe/tpm/cost/vo/in/SaleLimitVo.java <==
package com.chinayanghe.tpm.cost.vo.in;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 销售限制
 * SaleLimitDto
 * 数据库表：sale_limit
 */
public class SaleLimitVo implements Serializable {

    /**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	/**
     * 经商商编码
     */
    private String dealerCode;
    /**
     * 经销商名称
     */
    private String dealerName;
    /**
     * 核报单号
     * 表字段 : sale_limit.pay_no
     */
    private String payNo;
    
    List<SaleLimitProductVo> productList;
   
    /**
     * 人员编码
     */
    private String userName;
    /**
     * 人员名称
     */
    private String fullName;
	public String getPayNo() {
		return payNo;
	}
	public void setPayNo(String payNo) {
		this.payNo = payNo;
	}
	public String getDealerCode() {
		return dealerCode;
	}
	public void setDealerCode(String dealerCode) {
		this.dealerCode = dealerCode;
	}
	public String getDealerName() {
		return dealerName;
	}
	public void setDealerName(String dealerName) {
		this.dealerName = dealerName;
	}
	public String getUserName() {
		return userName;
	}
	public void setUserName(String userName) {
		this.userName = userName;
	}
	public String getFullName() {
		return fullName;
	}
	public void setFullName(String fullName) {
		this.fullName = fullName;
	}
	public List<SaleLimitProductVo> getProductList() {
		return productList;
	}
	public void setProductList(List<SaleLimitProductVo> productList) {
		this.productList = productList;
	}

   
    
    
}

==> cost-interface-0.3.45-sources.jar: com/chinayanghe/tpm/cost/vo/in/SaleLimitVo.java <==
package com.chinayanghe.tpm.cost.vo.in;

import java.io.Serializable;
import java.util.List;

/**
 * 销售限制
 * SaleLimitDto
 * 数据库表：sale_limit
 */
public class SaleLimitVo implements Serializable {

    /**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	
	//当前操作 A-冻结  B-驳回  C-审批
	private String opt="A";//操作
	/**
     * 经商商编码
     */
    private String dealerCode;
    /**
     * 经销商名称
     */
    private String dealerName;
    /**
     * 核报单号
     * 表字段 : sale_limit.pay_no
     */
    private String payNo;
    
    List<SaleLimitProductVo> productList;
   
    /**
     * 人员编码
     */
    private String userName;
    /**
     * 人员名称
     */
    private String fullName;
	public String getPayNo() {
		return payNo;
	}
	public void setPayNo(String payNo) {
		this.payNo = payNo;
	}
	public String getDealerCode() {
		return dealerCode;
	}
	public void setDealerCode(String dealerCode) {
		this.dealerCode = dealerCode;
	}
	public String getDealerName() {
		return dealerName;
	}
	public void setDealerName(String dealerName) {
		this.dealerName = dealerName;
	}
	public String getUserName() {
		return userName;
	}
	public void setUserName(String userName) {
		this.userName = userName;
	}
	public String getFullName() {
		return fullName;
	}
	public void setFullName(String fullName) {
		this.fullName = fullName;
	}
	public List<SaleLimitProductVo> getProductList() {
		return productList;
	}
	public void setProductList(List<SaleLimitProductVo> productList) {
		this.productList = productList;
	}
	public String getOpt() {
		return opt;
	}
	public void setOpt(String opt) {
		this.opt = opt;
	}

   
    
    
}
